@@ -1,7 +1,3 @@
-/*
- * $Id: plot2d.h,v 1.20 2017/01/14 06:23:22 sfeam Exp $
- */
-
 /* GNUPLOT - plot2d.h */
 
 /*[
@@ -38,33 +34,47 @@
 # define GNUPLOT_PLOT2D_H
 
 #include "syscfg.h"
+#include "axis.h"
+#include "gp_types.h"
+#include "gadgets.h"
 
 /* This allows a natural interpretation of providing only a single column in 'using' */
 #define default_smooth_weight(option) \
- (option == SMOOTH_BINS || option == SMOOTH_KDENSITY || \
-  option == SMOOTH_FREQUENCY)
+ (option == SMOOTH_BINS || option == SMOOTH_KDENSITY || option == SMOOTH_FREQUENCY)
 
 /* Variables of plot2d.c needed by other modules: */
 
 extern struct curve_points *first_plot;
 
-extern double boxwidth;
-extern TBOOLEAN boxwidth_is_absolute;
+#ifdef USE_POLAR_GRID
+typedef struct pgrid {
+    t_dgrid3d_mode mode;
+    int theta_segments;
+    int r_segments;
+    int norm_q;
+    TBOOLEAN kdensity;
+    double scale;
+    double rmin;
+    double rmax;
+} pgrid;
+extern pgrid polar_grid;
+extern pgrid default_polar_grid;
+#endif
 
 /* prototypes from plot2d.c */
 
-void plotrequest __PROTO((void));
-void refresh_bounds __PROTO((struct curve_points *first_plot, int nplots));
+void plotrequest(void);
+void refresh_bounds(struct curve_points *first_plot, int nplots);
+void polar_range_fiddling(struct axis *xaxis, struct axis *yaxis);
 
 /* internal and external variables */
-void cp_free __PROTO((struct curve_points *cp));
-void cp_extend __PROTO((struct curve_points *cp, int num));
+void cp_free(struct curve_points *cp);
+void cp_extend(struct curve_points *cp, int num);
 
-#include "gp_types.h"
-#include "gadgets.h"
-struct text_label *store_label __PROTO((struct text_label *, struct coordinate *,
-					int i, char * string, double colorval));
-void parse_plot_title __PROTO((struct curve_points *this_plot, 
-					char *xtitle, char *ytitle, TBOOLEAN *set_title));
+struct text_label *store_label(struct text_label *, struct coordinate *,
+				int i, char * string, double colorval);
+void parse_plot_title(struct curve_points *this_plot, 
+			char *xtitle, char *ytitle, TBOOLEAN *set_title);
+void reevaluate_plot_title(struct curve_points *this_plot);
 
 #endif /* GNUPLOT_PLOT2D_H */
