@@ -1,7 +1,3 @@
-/*
- * $Id: tables.h,v 1.91 2014/05/13 18:20:55 sfeam Exp $
- */
-
 /* GNUPLOT - tables.h */
 
 /*[
@@ -40,7 +36,7 @@
 #include "syscfg.h"
 
 
-typedef void (*parsefuncp_t) __PROTO((void));
+typedef void (*parsefuncp_t)(void);
 
 struct gen_ftable {
     const char *key;
@@ -68,37 +64,39 @@ enum plot_axes_id {
 /* plot smooth parameters in plot.h */
 
 /* options for 'save' command */
-enum save_id { SAVE_INVALID, SAVE_FUNCS, SAVE_TERMINAL, SAVE_SET, SAVE_VARS };
+enum save_id { SAVE_INVALID, SAVE_FUNCS, SAVE_TERMINAL, SAVE_SET, SAVE_VARS,
+		SAVE_FIT, SAVE_DATABLOCKS };
 
 /* options for 'show' and 'set' commands
  * this is rather big, we might be better off with a hash table */
 enum set_id {
     S_INVALID,
     S_ACTIONTABLE, S_ALL, S_ANGLES, S_ARROW, S_AUTOSCALE, S_BARS, S_BIND, S_BORDER,
-    S_BOXWIDTH, S_CLABEL, S_CLIP, S_CNTRPARAM, S_CNTRLABEL, S_CONTOUR, 
-    S_COLORSEQUENCE, S_DASHTYPE, S_DATA, S_DATAFILE,
-    S_FUNCTIONS, S_DGRID3D, S_DUMMY, S_ENCODING, S_DECIMALSIGN, S_FIT,
-    S_FONTPATH, S_FORMAT,
-    S_GRID, S_HIDDEN3D, S_HISTORY, S_HISTORYSIZE, S_ISOSAMPLES, S_KEY,
-    S_LABEL, S_LINK,
+    S_BOXDEPTH, S_BOXWIDTH, S_CLABEL, S_CLIP, S_CNTRPARAM, S_CNTRLABEL, S_CONTOUR,
+    S_COLOR, S_COLORMAP, S_COLORSEQUENCE, S_CONTOURFILL, S_CORNERPOLES,
+    S_DASHTYPE, S_DATA, S_DATAFILE, S_DECIMALSIGN, S_DGRID3D, S_DUMMY, S_ENCODING,
+    S_FIT, S_FONTPATH, S_FORMAT, S_FUNCTIONS, S_GRID, S_HELP,
+    S_HIDDEN3D, S_HISTORY, S_HISTORYSIZE, S_ISOSAMPLES, S_ISOTROPIC, S_PIXMAP,
+    S_JITTER, S_KEY, S_LABEL, S_LINK, S_NONLINEAR,
     S_LINESTYLE, S_LINETYPE, S_LOADPATH, S_LOCALE, S_LOGSCALE, S_MACROS,
     S_MAPPING, S_MARGIN, S_LMARGIN, S_RMARGIN, S_TMARGIN, S_BMARGIN, S_MISSING,
-#ifdef USE_MOUSE
+    S_MICRO, S_MINUS_SIGN,
     S_MOUSE,
-#endif
-    S_MULTIPLOT, S_MX2TICS, S_NOMX2TICS, S_MXTICS, S_NOMXTICS,
+    S_MONOCHROME, S_MULTIPLOT, S_MX2TICS, S_NOMX2TICS, S_MXTICS, S_NOMXTICS,
     S_MY2TICS, S_NOMY2TICS, S_MYTICS, S_NOMYTICS,
-    S_MZTICS, S_NOMZTICS, S_MRTICS, S_NOMRTICS,
-    S_OFFSETS, S_ORIGIN, SET_OUTPUT, S_PARAMETRIC,
+    S_MZTICS, S_NOMZTICS, S_MRTICS,
+    S_OFFSETS, S_ORIGIN, SET_OUTPUT, S_OVERFLOW, S_PARAMETRIC,
     S_PALETTE, S_PM3D, S_COLORBOX, S_COLORNAMES,
     S_CBLABEL, S_CBRANGE, S_CBTICS, S_NOCBTICS, S_MCBTICS, S_NOMCBTICS,
-    S_CBDATA, S_CBDTICS, S_NOCBDTICS, S_CBMTICS, S_NOCBMTICS, S_OBJECT,
+    S_CBDATA, S_CBDTICS, S_NOCBDTICS, S_CBMTICS, S_NOCBMTICS, S_OBJECT, S_WALL,
     S_PLOT, S_POINTINTERVALBOX, S_POINTSIZE, S_POLAR, S_PRINT, S_PSDIR,
-    S_SAMPLES, S_SIZE, S_SURFACE, S_STYLE, 
-    S_TABLE, S_TERMINAL, S_TERMOPTIONS,
+    S_RGBMAX, S_SAMPLES, S_SIZE, S_SURFACE, S_STYLE, S_SPIDERPLOT,
+    S_TABLE, S_TERMINAL, S_TERMOPTIONS, S_THETA,
     S_TICS, S_TICSCALE, S_TICSLEVEL, S_TIMEFMT, S_TIMESTAMP, S_TITLE,
     S_TRANGE, S_URANGE, S_VARIABLES, S_VERSION, S_VIEW, S_VRANGE,
 
+    S_VGRID, S_VXRANGE, S_VYRANGE, S_VZRANGE, S_ISOSURFACE,
+
     S_X2DATA, S_X2DTICS, S_NOX2DTICS, S_X2LABEL, S_X2MTICS, S_NOX2MTICS,
     S_X2RANGE, S_X2TICS, S_NOX2TICS,
     S_XDATA, S_XDTICS, S_NOXDTICS, S_XLABEL, S_XMTICS, S_NOXMTICS, S_XRANGE,
@@ -112,10 +110,12 @@ enum set_id {
     S_ZDATA, S_ZDTICS, S_NOZDTICS, S_ZLABEL, S_ZMTICS, S_NOZMTICS, S_ZRANGE,
     S_ZTICS, S_NOZTICS,
 
-    S_RTICS, S_NORTICS, S_RRANGE, S_RAXIS, S_PAXIS,
+    S_RTICS, S_RRANGE, S_RAXIS, S_RLABEL, S_PAXIS, S_TTICS, S_MTTICS, 
 
     S_ZERO, S_ZEROAXIS, S_XZEROAXIS, S_X2ZEROAXIS, S_YZEROAXIS, S_Y2ZEROAXIS,
-    S_ZZEROAXIS
+    S_ZZEROAXIS,
+    S_WATCH, S_WARNINGS,
+    S_DEBUG
 };
 
 enum set_hidden3d_id {
@@ -130,7 +130,7 @@ enum set_key_id {
     S_KEY_INVALID,
     S_KEY_TOP, S_KEY_BOTTOM, S_KEY_LEFT, S_KEY_RIGHT, S_KEY_CENTER,
     S_KEY_VERTICAL, S_KEY_HORIZONTAL, S_KEY_OVER, S_KEY_UNDER, S_KEY_MANUAL,
-    S_KEY_INSIDE, S_KEY_OUTSIDE, S_KEY_ABOVE, S_KEY_BELOW,
+    S_KEY_INSIDE, S_KEY_OUTSIDE, S_KEY_FIXED, S_KEY_ABOVE, S_KEY_BELOW,
     S_KEY_TMARGIN, S_KEY_BMARGIN, S_KEY_LMARGIN, S_KEY_RMARGIN,
     S_KEY_LLEFT, S_KEY_RRIGHT, S_KEY_REVERSE, S_KEY_NOREVERSE,
     S_KEY_INVERT, S_KEY_NOINVERT,
@@ -140,16 +140,17 @@ enum set_key_id {
     S_KEY_FONT, S_KEY_TEXTCOLOR,
     S_KEY_AUTOTITLES, S_KEY_NOAUTOTITLES,
     S_KEY_DEFAULT, S_KEY_ON, S_KEY_OFF,
-    S_KEY_MAXCOLS, S_KEY_MAXROWS,
-    S_KEY_FRONT, S_KEY_NOFRONT
+    S_KEY_KEYWIDTH, S_KEY_COLS, S_KEY_MAXCOLS, S_KEY_MAXROWS,
+    S_KEY_FRONT, S_KEY_NOFRONT, S_KEY_OFFSET
 };
 
 enum set_colorbox_id {
     S_COLORBOX_INVALID,
     S_COLORBOX_VERTICAL, S_COLORBOX_HORIZONTAL,
-    S_COLORBOX_DEFAULT, S_COLORBOX_USER,
-    S_COLORBOX_BORDER, S_COLORBOX_BDEFAULT, S_COLORBOX_NOBORDER,
+    S_COLORBOX_DEFAULT, S_COLORBOX_USER, S_COLORBOX_BOTTOM,
     S_COLORBOX_ORIGIN, S_COLORBOX_SIZE,
+    S_COLORBOX_BORDER, S_COLORBOX_BDEFAULT, S_COLORBOX_NOBORDER,
+    S_COLORBOX_INVERT, S_COLORBOX_NOINVERT,
     S_COLORBOX_FRONT, S_COLORBOX_BACK
 };
 
@@ -158,8 +159,8 @@ enum set_palette_id {
     S_PALETTE_POSITIVE, S_PALETTE_NEGATIVE,
     S_PALETTE_GRAY, S_PALETTE_COLOR, S_PALETTE_RGBFORMULAE,
     S_PALETTE_NOPS_ALLCF, S_PALETTE_PS_ALLCF, S_PALETTE_MAXCOLORS,
-    S_PALETTE_DEFINED, S_PALETTE_FILE, S_PALETTE_FUNCTIONS,
-    S_PALETTE_MODEL, S_PALETTE_GAMMA, S_PALETTE_CUBEHELIX
+    S_PALETTE_COLORMAP, S_PALETTE_DEFINED, S_PALETTE_FILE, S_PALETTE_FUNCTIONS,
+    S_PALETTE_MODEL, S_PALETTE_GAMMA, S_PALETTE_CUBEHELIX, S_PALETTE_VIRIDIS,
 };
 
 enum set_pm3d_id {
@@ -169,11 +170,12 @@ enum set_pm3d_id {
     S_PM3D_SCANSFORWARD, S_PM3D_SCANSBACKWARD, S_PM3D_SCANS_AUTOMATIC,
     S_PM3D_DEPTH,
     S_PM3D_FLUSH, S_PM3D_FTRIANGLES, S_PM3D_NOFTRIANGLES,
-    S_PM3D_CLIP_1IN, S_PM3D_CLIP_4IN,
+    S_PM3D_CLIP_Z, S_PM3D_CLIP_1IN, S_PM3D_CLIP_4IN, S_PM3D_CLIPCB, S_PM3D_NOCLIPCB,
     S_PM3D_MAP, S_PM3D_BORDER, S_PM3D_NOBORDER, S_PM3D_HIDDEN, S_PM3D_NOHIDDEN,
     S_PM3D_SOLID, S_PM3D_NOTRANSPARENT, S_PM3D_NOSOLID, S_PM3D_TRANSPARENT,
     S_PM3D_IMPLICIT, S_PM3D_NOEXPLICIT, S_PM3D_NOIMPLICIT, S_PM3D_EXPLICIT,
-    S_PM3D_WHICH_CORNER
+    S_PM3D_WHICH_CORNER,
+    S_PM3D_LIGHTING_MODEL, S_PM3D_NOLIGHTING_MODEL, S_PM3D_SPOTLIGHT
 };
 
 enum test_id {
@@ -188,21 +190,20 @@ enum show_style_id {
     SHOW_STYLE_FILLING, SHOW_STYLE_ARROW, 
     SHOW_STYLE_CIRCLE, SHOW_STYLE_ELLIPSE, SHOW_STYLE_RECTANGLE,
     SHOW_STYLE_INCREMENT, SHOW_STYLE_HISTOGRAM, SHOW_STYLE_BOXPLOT,
-    SHOW_STYLE_PARALLEL
-#ifdef EAM_BOXED_TEXT
-    , SHOW_STYLE_TEXTBOX
-#endif
+    SHOW_STYLE_PARALLEL, SHOW_STYLE_SPIDERPLOT,
+    SHOW_STYLE_TEXTBOX, SHOW_STYLE_WATCHPOINT
 };
 
 enum filledcurves_opts_id {
-    FILLEDCURVES_CLOSED,
+    FILLEDCURVES_CLOSED=0,
     FILLEDCURVES_X1, FILLEDCURVES_Y1, FILLEDCURVES_X2, FILLEDCURVES_Y2,
     /* requirement: FILLEDCURVES_ATX1 = FILLEDCURVES_X1+4 */
     FILLEDCURVES_ATX1, FILLEDCURVES_ATY1, FILLEDCURVES_ATX2, FILLEDCURVES_ATY2,
     FILLEDCURVES_ATXY,
     FILLEDCURVES_ATR,
     FILLEDCURVES_ABOVE, FILLEDCURVES_BELOW,
-    FILLEDCURVES_BETWEEN
+    FILLEDCURVES_BETWEEN,
+    FILLEDCURVES_DEFAULT
 };
 
 extern const struct gen_table command_tbl[];
@@ -220,6 +221,7 @@ extern const struct gen_table color_model_tbl[];
 extern const struct gen_table set_hidden3d_tbl[];
 extern const struct gen_table show_style_tbl[];
 extern const struct gen_table plotstyle_tbl[];
+extern const struct gen_table fit_verbosity_level[];
 
 /* EAM Nov 2008 - this is now dynamic, so we can add colors on the fly */
 extern       struct gen_table *user_color_names_tbl;
@@ -232,12 +234,13 @@ extern const struct gen_ftable command_ftbl[];
 extern const struct gen_table filledcurves_opts_tbl[];
 
 /* Function prototypes */
-int lookup_table __PROTO((const struct gen_table *, int));
-parsefuncp_t lookup_ftable __PROTO((const struct gen_ftable *, int));
-int lookup_table_entry __PROTO((const struct gen_table *tbl, const char *search_str));
-int lookup_table_nth __PROTO((const struct gen_table *tbl, const char *search_str));
-int lookup_table_nth_reverse __PROTO((const struct gen_table *tbl, int table_len, const char *search_str));
-const char * reverse_table_lookup __PROTO((const struct gen_table *tbl, int entry));
+int lookup_table(const struct gen_table *, int);
+parsefuncp_t lookup_ftable(const struct gen_ftable *, int);
+int lookup_table_entry(const struct gen_table *tbl, const char *search_str);
+int lookup_table_nth(const struct gen_table *tbl, const char *search_str);
+int lookup_table_nth_reverse(const struct gen_table *tbl, int table_len, const char *search_str);
+const char * reverse_table_lookup(const struct gen_table *tbl, int entry);
+char * clean_reverse_table_lookup(const struct gen_table *tbl, int entry);
 
 
 #endif /* GNUPLT_TABLES_H */
